[PATCH] misc: Fix typos in the comments

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/osmocom-net-gprs@lists.osmocom.org/.

Holger Hans Peter Freyther hfreyther at sysmocom.de
Mon Jul 23 08:30:01 UTC 2012


From: Holger Hans Peter Freyther <holger at freyther.de>

ressource -> resorce
shure     -> sure
---
 src/gprs_bssgp_pcu.cpp    |    4 ++--
 src/gprs_rlcmac.cpp       |   14 +++++++-------
 src/gprs_rlcmac.h         |    2 +-
 src/gprs_rlcmac_data.cpp  |   10 +++++-----
 src/gprs_rlcmac_sched.cpp |   20 ++++++++++----------
 src/tbf.txt               |    2 +-
 6 files changed, 26 insertions(+), 26 deletions(-)

diff --git a/src/gprs_bssgp_pcu.cpp b/src/gprs_bssgp_pcu.cpp
index 217acdb..dc8e454 100644
--- a/src/gprs_bssgp_pcu.cpp
+++ b/src/gprs_bssgp_pcu.cpp
@@ -190,7 +190,7 @@ int gprs_bssgp_pcu_rx_dl_ud(struct msgb *msg, struct tlv_parsed *tp)
 		// Create new TBF (any TRX)
 		tfi = tfi_alloc(GPRS_RLCMAC_DL_TBF, &trx, &ts, use_trx, first_ts);
 		if (tfi < 0) {
-			LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH ressource\n");
+			LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH resource\n");
 			/* FIXME: send reject */
 			return -EBUSY;
 		}
@@ -198,7 +198,7 @@ int gprs_bssgp_pcu_rx_dl_ud(struct msgb *msg, struct tlv_parsed *tp)
 		tbf = tbf_alloc(tbf, GPRS_RLCMAC_DL_TBF, tfi, trx, ts, ms_class,
 			ss);
 		if (!tbf) {
-			LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH ressource\n");
+			LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH resource\n");
 			/* FIXME: send reject */
 			return -EBUSY;
 		}
diff --git a/src/gprs_rlcmac.cpp b/src/gprs_rlcmac.cpp
index d1f0b54..5284260 100644
--- a/src/gprs_rlcmac.cpp
+++ b/src/gprs_rlcmac.cpp
@@ -80,7 +80,7 @@ llist_head *gprs_rlcmac_tbfs_lists[] = {
 };
 void *rlcmac_tall_ctx;
 
-/* FIXME: spread ressources over multiple TRX. Also add option to use same
+/* FIXME: spread resources over multiple TRX. Also add option to use same
  * TRX in case of existing TBF for TLLI in the other direction. */
 /* search for free TFI and return TFI, TRX and first TS */
 int tfi_alloc(enum gprs_rlcmac_tbf_direction dir, uint8_t *_trx, uint8_t *_ts,
@@ -264,7 +264,7 @@ struct gprs_rlcmac_tbf *tbf_alloc(struct gprs_rlcmac_tbf *old_tbf,
 	else
 		rc = bts->alloc_algorithm(old_tbf, tbf,
 			bts->alloc_algorithm_curst);
-	/* if no ressource */
+	/* if no resource */
 	if (rc < 0) {
 		talloc_free(tbf);
 		return NULL;
@@ -272,7 +272,7 @@ struct gprs_rlcmac_tbf *tbf_alloc(struct gprs_rlcmac_tbf *old_tbf,
 	/* assign control ts */
 	tbf->control_ts = 0xff;
 	rc = tbf_assign_control_ts(tbf);
-	/* if no ressource */
+	/* if no resource */
 	if (rc < 0) {
 		talloc_free(tbf);
 		return NULL;
@@ -767,12 +767,12 @@ void tbf_free(struct gprs_rlcmac_tbf *tbf)
 		LOGP(DRLCMAC, LOGL_ERROR, "Software error: Pending uplink "
 			"assignment. This may not happen, because the "
 			"assignment message never gets transmitted. Please "
-			"be shure not to free in this state. PLEASE FIX!\n");
+			"be sure not to free in this state. PLEASE FIX!\n");
 	if (tbf->dl_ass_state != GPRS_RLCMAC_DL_ASS_NONE)
 		LOGP(DRLCMAC, LOGL_ERROR, "Software error: Pending downlink "
 			"assignment. This may not happen, because the "
 			"assignment message never gets transmitted. Please "
-			"be shure not to free in this state. PLEASE FIX!\n");
+			"be sure not to free in this state. PLEASE FIX!\n");
 	tbf_timer_stop(tbf);
 	while ((msg = msgb_dequeue(&tbf->llc_queue)))
 		msgb_free(msg);
@@ -802,9 +802,9 @@ int tbf_update(struct gprs_rlcmac_tbf *tbf)
 
 	tbf_unlink_pdch(tbf);
 	rc = bts->alloc_algorithm(ul_tbf, tbf, bts->alloc_algorithm_curst);
-	/* if no ressource */
+	/* if no resource */
 	if (rc < 0) {
-		LOGP(DRLCMAC, LOGL_ERROR, "No ressource after update???\n");
+		LOGP(DRLCMAC, LOGL_ERROR, "No resource after update???\n");
 		return -rc;
 	}
 
diff --git a/src/gprs_rlcmac.h b/src/gprs_rlcmac.h
index 71ff608..fbae677 100644
--- a/src/gprs_rlcmac.h
+++ b/src/gprs_rlcmac.h
@@ -99,7 +99,7 @@ extern struct gprs_rlcmac_bts *gprs_rlcmac_bts;
 enum gprs_rlcmac_tbf_state {
 	GPRS_RLCMAC_NULL = 0,	/* new created TBF */
 	GPRS_RLCMAC_ASSIGN,	/* wait for downlink assignment */
-	GPRS_RLCMAC_FLOW,	/* RLC/MAC flow, ressource needed */
+	GPRS_RLCMAC_FLOW,	/* RLC/MAC flow, resource needed */
 	GPRS_RLCMAC_FINISHED,	/* flow finished, wait for release */
 	GPRS_RLCMAC_WAIT_RELEASE,/* wait for release or restart of DL TBF */
 	GPRS_RLCMAC_RELEASING,	/* releasing, wait to free TBI/USF */
diff --git a/src/gprs_rlcmac_data.cpp b/src/gprs_rlcmac_data.cpp
index 2f67bd0..b56d63d 100644
--- a/src/gprs_rlcmac_data.cpp
+++ b/src/gprs_rlcmac_data.cpp
@@ -220,7 +220,7 @@ uplink_request:
 			/* create new TBF, use sme TRX as DL TBF */
 			tfi = tfi_alloc(GPRS_RLCMAC_UL_TBF, &trx, &ts, tbf->trx, tbf->first_ts);
 			if (tfi < 0) {
-				LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH ressource\n");
+				LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH resource\n");
 				/* FIXME: send reject */
 				break;
 			}
@@ -228,7 +228,7 @@ uplink_request:
 			ul_tbf = tbf_alloc(tbf, GPRS_RLCMAC_UL_TBF, tfi, trx,
 				ts, tbf->ms_class, 0);
 			if (!ul_tbf) {
-				LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH ressource\n");
+				LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH resource\n");
 				/* FIXME: send reject */
 				break;
 			}
@@ -269,7 +269,7 @@ uplink_request:
 			}
 			tlli = tbf->tlli;
 		}
-		LOGP(DRLCMAC, LOGL_ERROR, "RX: [PCU <- BTS] %s TFI: %u TLLI: 0x%08x FIXME: Packet ressource request\n", (tbf->direction == GPRS_RLCMAC_UL_TBF) ? "UL" : "DL", tbf->tfi, tbf->tlli);
+		LOGP(DRLCMAC, LOGL_ERROR, "RX: [PCU <- BTS] %s TFI: %u TLLI: 0x%08x FIXME: Packet resource request\n", (tbf->direction == GPRS_RLCMAC_UL_TBF) ? "UL" : "DL", tbf->tfi, tbf->tlli);
 		break;
 	default:
 		LOGP(DRLCMAC, LOGL_NOTICE, "RX: [PCU <- BTS] unknown control block received\n");
@@ -838,14 +838,14 @@ int gprs_rlcmac_rcv_rach(uint8_t ra, uint32_t Fn, int16_t qta)
 	// Create new TBF
 	tfi = tfi_alloc(GPRS_RLCMAC_UL_TBF, &trx, &ts, -1, -1);
 	if (tfi < 0) {
-		LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH ressource\n");
+		LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH resource\n");
 		/* FIXME: send reject */
 		return -EBUSY;
 	}
 	/* set class to 0, since we don't know the multislot class yet */
 	tbf = tbf_alloc(NULL, GPRS_RLCMAC_UL_TBF, tfi, trx, ts, 0, 1);
 	if (!tbf) {
-		LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH ressource\n");
+		LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH resource\n");
 		/* FIXME: send reject */
 		return -EBUSY;
 	}
diff --git a/src/tbf.txt b/src/tbf.txt
index eab58ba..025e56c 100644
--- a/src/tbf.txt
+++ b/src/tbf.txt
@@ -118,7 +118,7 @@ Control TS:
 Polling:
   In order to poll uplink control block from MS, a special poll state and
   frame number is stored at TBF. The scheduler reads that value and will not
-  assign uplink ressource for other TBFs at that frame number.
+  assign uplink resource for other TBFs at that frame number.
 
   When there is no uplink transmission received on the block, a timeout is
   indicated by layer 1 interface. There are two ways of checking timeout:
diff --git a/src/gprs_rlcmac_sched.cpp b/src/gprs_rlcmac_sched.cpp
index f6af9b7..83a89ac 100644
--- a/src/gprs_rlcmac_sched.cpp
+++ b/src/gprs_rlcmac_sched.cpp
@@ -90,7 +90,7 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 			ul_ass_tbf = tbf;
 	}
 
 	/* check uplink ressource for polling */
 	if (poll_tbf) {
 		LOGP(DRLCMACSCHED, LOGL_DEBUG, "Received RTS for PDCH: TRX=%d "
 			"TS=%d FN=%d block_nr=%d scheduling free USF for "
@@ -99,17 +99,17 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 			(tbf->direction == GPRS_RLCMAC_UL_TBF) ? "UL" : "DL",
 			poll_tbf->tfi);
 		/* use free USF */
-	/* else, we search for uplink ressource */
+	/* else, we search for uplink resource */
 	} else {
 		/* select uplink ressource */
 		for (i = 0, tfi = pdch->next_ul_tfi; i < 32;
 		     i++, tfi = (tfi + 1) & 31) {
 			tbf = pdch->ul_tbf[tfi];
 			/* no TBF for this tfi, go next */
 			if (!tbf)
 				continue;
-			/* no UL ressources needed, go next */
-			/* we don't need to give ressources in FINISHED state,
+			/* no UL resources needed, go next */
+			/* we don't need to give resources in FINISHED state,
 			 * because we have received all blocks and only poll
 			 * for packet control ack. */
 			if (tbf->state != GPRS_RLCMAC_FLOW)
@@ -119,9 +119,9 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 			usf = tbf->dir.ul.usf[ts];
 			LOGP(DRLCMACSCHED, LOGL_DEBUG, "Received RTS for PDCH: "
 				"TRX=%d TS=%d FN=%d block_nr=%d scheduling "
-				"USF=%d for required uplink ressource of "
+				"USF=%d for required uplink resource of "
 				"UL TBF=%d\n", trx, ts, fn, block_nr, usf, tfi);
 			/* next TBF to handle ressource is the next one */
 			pdch->next_ul_tfi = (tfi + 1) & 31;
 			break;
 		}
@@ -160,7 +160,7 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 
 	/* Prio 2: select data message for downlink */
 	if (!msg) {
 		/* select downlink ressource */
 		for (i = 0, tfi = pdch->next_dl_tfi; i < 32;
 		     i++, tfi = (tfi + 1) & 31) {
 			tbf = pdch->dl_tbf[tfi];
@@ -170,7 +170,7 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 			/* no DL TBF, go next */
 			if (tbf->direction != GPRS_RLCMAC_DL_TBF)
 				continue;
-			/* no DL ressources needed, go next */
+			/* no DL resources needed, go next */
 			if (tbf->state != GPRS_RLCMAC_FLOW
 			 && tbf->state != GPRS_RLCMAC_FINISHED)
 				continue;
@@ -178,7 +178,7 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 			LOGP(DRLCMACSCHED, LOGL_DEBUG, "Scheduling data "
 				"message at RTS for DL TBF=%d (TRX=%d, "
 				"TS=%d)\n", tfi, trx, ts);
 			/* next TBF to handle ressource is the next one */
 			pdch->next_dl_tfi = (tfi + 1) & 31;
 			/* generate DL data block */
 			msg = gprs_rlcmac_send_data_block_acknowledged(tbf, fn,
@@ -90,7 +90,7 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 	}
 
-	/* check uplink ressource for polling */
+	/* check uplink resource for polling */
 	if (poll_tbf) {
 		LOGP(DRLCMACSCHED, LOGL_DEBUG, "Received RTS for PDCH: TRX=%d "
@@ -99,17 +99,17 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 	} else {
-		/* select uplink ressource */
+		/* select uplink resource */
 		for (i = 0, tfi = pdch->next_ul_tfi; i < 32;
 		     i++, tfi = (tfi + 1) & 31) {
@@ -119,9 +119,9 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 				"UL TBF=%d\n", trx, ts, fn, block_nr, usf, tfi);
-			/* next TBF to handle ressource is the next one */
+			/* next TBF to handle resource is the next one */
 			pdch->next_ul_tfi = (tfi + 1) & 31;
 			break;
@@ -160,7 +160,7 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 	/* Prio 2: select data message for downlink */
 	if (!msg) {
-		/* select downlink ressource */
+		/* select downlink resource */
 		for (i = 0, tfi = pdch->next_dl_tfi; i < 32;
 		     i++, tfi = (tfi + 1) & 31) {
@@ -178,7 +178,7 @@ int gprs_rlcmac_rcv_rts_block(uint8_t trx, uint8_t ts, uint16_t arfcn,
 				"message at RTS for DL TBF=%d (TRX=%d, "
 				"TS=%d)\n", tfi, trx, ts);
-			/* next TBF to handle ressource is the next one */
+			/* next TBF to handle resource is the next one */
 			pdch->next_dl_tfi = (tfi + 1) & 31;
 			/* generate DL data block */
-- 
1.7.10.4





More information about the osmocom-net-gprs mailing list